@@ -25,8 +25,11 @@ from retrying import retry
 from libcloud.storage.providers import get_driver, Provider
 from medusa import utils
 
+MAX_UP_DOWN_LOAD_RETRIES = 5
+
 
 class AwsCli(object):
+
     def __init__(self, storage):
         self._config = storage.config
         self.storage = storage
@@ -36,15 +39,24 @@ class AwsCli(object):
         return self._config.bucket_name
 
     def __enter__(self):
+        self._env = os.environ.copy()
+
+        if self._config.api_profile:
+            self._env['AWS_PROFILE'] = self._config.api_profile
+
         if self._config.key_file:
-            self._env = dict(os.environ, AWS_SHARED_CREDENTIALS_FILE=self._config.key_file)
-        else:
-            self._env = dict(os.environ)
+            self._env['AWS_SHARED_CREDENTIALS_FILE'] = self._config.key_file
+
+        if self._config.region and self._config.region != "default":
+            self._env['AWS_REGION'] = self._config.region
+        elif self._config.storage_provider not in [Provider.S3, "s3_compatible"] and self._config.region == "default":
+            # Legacy libcloud S3 providers that were tied to a specific region such as s3_us_west_oregon
+            self._env['AWS_REGION'] = get_driver(self._config.storage_provider).region_name
 
         if self._config.aws_cli_path == 'dynamic':
-            self._aws_cli_path = self.find_aws_cli()
+            self._aws_cli_cmd = self.cmd()
         else:
-            self._aws_cli_path = self._config.aws_cli_path
+            self._aws_cli_cmd = [self._config.aws_cli_path]
 
         self.endpoint_url = None
         if self._config.host is not None:
@@ -62,23 +74,8 @@ class AwsCli(object):
         return False
 
     @staticmethod
-    def find_aws_cli():
-        """
-        Construct the AWS command line with parameters and variables
-        Also includes a lookup for the AWS binary, in case we are running
-        under a venv
-        """
-        aws_bin = 'aws'
-        binary_paths = ['/usr/bin', '/usr/local/bin']
-        paths = sys.path + binary_paths
-        for path in paths:
-            if not path:
-                continue
-            tpath = '/'.join([path, 'aws'])
-            if os.path.exists(tpath) and os.path.isfile(tpath) and os.access(tpath, os.X_OK):
-                aws_bin = tpath
-                break
-        return aws_bin
+    def cmd():
+        return [sys.executable, '-m', 'awscli']
 
     def cp_upload(self, *, srcs, bucket_name, dest, max_retries=5):
         job_id = str(uuid.uuid4())
@@ -102,20 +99,16 @@ class AwsCli(object):
         return objects
 
     def _create_s3_cmd(self):
-        cmd = [self._aws_cli_path]
+        cmd = self._aws_cli_cmd.copy()
 
         if self.endpoint_url is not None:
             cmd.extend(["--endpoint-url", self.endpoint_url])
 
-        if self._config.region is not None and self._config.region != "default":
-            cmd.extend(["--region", self._config.region])
-        elif self._config.storage_provider != Provider.S3 and self._config.region == "default":
-            # Legacy libcloud S3 providers that were tied to a specific region such as s3_us_west_oregon
-            cmd.extend(["--region", get_driver(self._config.storage_provider).region_name])
-
         return cmd
 
-    @retry(stop_max_attempt_number=5, wait_fixed=5000)
+    @retry(
+        stop_max_attempt_number=MAX_UP_DOWN_LOAD_RETRIES,
+        wait_exponential_multiplier=10000, wait_exponential_max=120000)
     def upload_file(self, cmd, dest, awscli_output):
         logging.debug(" ".join(cmd))
         with open(awscli_output, "w") as output:
@@ -139,7 +132,9 @@ class AwsCli(object):
             )
         )
 
-    @retry(stop_max_attempt_number=5, wait_fixed=5000)
+    @retry(
+        stop_max_attempt_number=MAX_UP_DOWN_LOAD_RETRIES,
+        wait_exponential_multiplier=10000, wait_exponential_max=120000)
     def download_file(self, cmd, dest, awscli_output):
         logging.debug(" ".join(cmd))
         with open(awscli_output, "w") as output:
@@ -162,7 +157,9 @@ class AwsCli(object):
             )
         )
 
-    @retry(stop_max_attempt_number=10, wait_fixed=1000)
+    @retry(
+        stop_max_attempt_number=MAX_UP_DOWN_LOAD_RETRIES,
+        wait_exponential_multiplier=10000, wait_exponential_max=120000)
     def get_blob(self, blob_name):
         # This needs to be retried as S3 is eventually consistent
         obj = self.storage.get_blob(blob_name)
